import numpy as np
import os
import shutil
from sklearn.utils import shuffle
from utility import cross_validation_scheme
from sklearn.metrics import r2_score,  mean_absolute_error

# Load in descriptor and target energies for training and transfer-learning sets
descriptor_DMB_train = np.loadtxt('../data/ml_data/descriptor_DMB_train.dat')
descriptor_DMB_leave_out_test = np.loadtxt('../data/ml_data/descriptor_DMB_leave_out_test.dat')

lambda_DMB_train = np.loadtxt('../data/ml_data/lambda_DMB_train.dat')
lambda_DMB_leave_out_test = np.loadtxt('../data/ml_data/lambda_DMB_leave_out_test.dat')


# Generalize variable names to X_train and Y_train
X_train = descriptor_DMB_train
Y_train = lambda_DMB_train

X_leave_out_test = descriptor_DMB_leave_out_test
Y_leave_out_test = lambda_DMB_leave_out_test

# Print major stats
print('\n')
print('Train Data Size: ', X_train.shape)
print('Max feature value: %.3f' % X_train.max())
print('Mean feature value: %.3f' % X_train.mean())
print('Min feature value: %.3f' % X_train.min())
print('Std feature value: %.3f' % X_train.std())
print('\n')

# Define number of cross-validation (cv) fold
number_of_cross_validation_fold = 5

# Perform model fitting with cross validation
cvs = cross_validation_scheme(X_train, Y_train, n_cv=number_of_cross_validation_fold)
mae_leave_out_test = []
r2_leave_out_test = []

for i in range(number_of_cross_validation_fold):
    mae_per_fold = mean_absolute_error(Y_leave_out_test, cvs['estimator'][i].predict(X_leave_out_test))
    mae_leave_out_test.append(mae_per_fold)

    r2_per_fold = r2_score(Y_leave_out_test, cvs['estimator'][i].predict(X_leave_out_test))
    r2_leave_out_test.append(r2_per_fold)

print('\n')
print('r2 for leave out testing set: %.3f ' %np.array(r2_leave_out_test).mean())
print('MAE for leave out testing set: %.2f nm ' %np.array(mae_leave_out_test).mean()) 
